#line 2 "proslex.C"

#line 4 "proslex.C"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

    /* The c++ scanner is a mess. The FlexLexer.h header file relies on the
     * following macro. This is required in order to pass the c++-multiple-scanners
     * test in the regression suite. We get reports that it breaks inheritance.
     * We will address this in a future release of flex, or omit the C++ scanner
     * altogether.
     */
    #define yyFlexLexer prosFlexLexer

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
typedef uint64_t flex_uint64_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */
#include <iostream> 
#include <errno.h>
#include <cstdlib>
#include <cstring>
/* end standard C++ headers. */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t yyleng;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{

	std::istream* yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

void *prosalloc (yy_size_t  );
void *prosrealloc (void *,yy_size_t  );
void prosfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

#define yytext_ptr yytext

#include <FlexLexer.h>

int yyFlexLexer::yywrap() { return 1; }

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (yy_size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 52
#define YY_END_OF_BUFFER 53
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[198] =
    {   0,
        0,    0,    2,    2,   53,   51,   47,   50,   51,   51,
       51,   51,   51,   22,   46,   46,   46,   46,   46,   46,
       46,   46,   46,   14,   46,   46,   46,   46,   51,   51,
        2,    1,   47,   48,    0,   43,    0,   44,    0,   22,
       24,   33,   29,   23,   22,    0,   46,   25,   46,   46,
       27,   46,   46,   46,   46,   46,   46,   46,   46,   46,
       46,   46,   46,   16,   46,   46,   46,   46,   49,    0,
       45,    2,   24,   35,   31,   23,   25,    0,    0,   27,
       34,   30,   26,    0,   28,   25,    0,   46,    0,   23,
       46,   46,   46,    5,   46,   46,   46,   46,   46,   46,

       46,   46,   15,   46,   46,   46,   46,   46,   36,   32,
        0,   23,    0,    0,   24,    0,   46,   46,   46,   46,
       46,   46,   46,   46,   46,   46,   46,   46,   46,   46,
       46,   46,   46,    0,    0,    0,   37,    0,   46,    0,
       46,   46,    4,   46,    7,   46,   46,   46,   46,   12,
       46,   46,   18,   46,   46,   46,    0,    0,   38,   37,
        0,    0,   41,    0,    0,   39,   46,    6,   46,   46,
       46,   46,   46,   46,   46,   20,   46,   41,   39,   42,
       40,    3,   46,    8,   46,   46,   13,   46,   19,   21,
        9,   46,   11,   17,   46,   10,    0

    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    5,    1,    1,    1,    1,    6,    1,
        1,    1,    7,    1,    7,    8,    1,    9,   10,   11,
       12,   12,   13,   12,   12,   12,   14,   15,    1,    1,
        1,    1,    1,    1,   16,   17,   18,   19,   20,   21,
       22,   23,   24,   25,   26,   27,   28,   29,   30,   31,
       32,   33,   34,   35,   36,   37,   26,   38,   39,   26,
        1,   40,    1,    1,    1,    1,   41,   42,   43,   44,

       45,   46,   47,   48,   49,   50,   26,   51,   52,   53,
       54,   55,   56,   57,   58,   59,   60,   61,   26,   62,
       63,   26,   64,    1,   65,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[66] =
    {   0,
        1,    1,    2,    1,    3,    3,    1,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    1,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    1,    1
    } ;

static yyconst flex_int16_t yy_base[204] =
    {   0,
        0,    0,  134,  131,  130, 1540,  123, 1540,  121,  116,
      114,   58,   64,   74,   94,   98,   90,  121,  162,  127,
      138,  150,  154,  166,  170,  187,  182,  214,   62,   52,
        0, 1540,  114, 1540,   96, 1540,   86, 1540,  233,  255,
      308, 1540, 1540,  361,  414,  239,  222,  467,  478,  270,
      281,  286,  318,  330,  301,  342,  380,  385,  396,  489,
      433,  495,  500,  438,  459,  520,  524,  528, 1540,   25,
     1540,    0,  581, 1540, 1540,  634,  539,  553,  563, 1540,
     1540, 1540, 1540,  595, 1540, 1540,  606,  621,  646,  105,
      673,  656,  455,  573,  688,  692,  705,  709,  729,  733,

      660,  745,  751,  756,  767,  771,  783,  787, 1540, 1540,
      794,  818,  826,  838,  850,  857,  872,  880,  890,  894,
      905,  811,  913,  918,  930,  942,  946,  961,  966,  972,
      978,  986,  990, 1009, 1024,  863, 1033,  999, 1041, 1047,
     1093, 1057, 1061, 1065, 1073, 1081, 1103, 1114, 1118, 1126,
     1130, 1142, 1150, 1158, 1164, 1175, 1183, 1210, 1197, 1221,
     1236, 1242, 1252, 1252, 1268, 1282, 1290, 1298, 1303, 1314,
     1325, 1330, 1336, 1356, 1341, 1360, 1375, 1540, 1540, 1540,
     1540, 1380, 1393, 1397, 1401, 1409, 1414, 1426, 1432, 1440,
     1451, 1455, 1459, 1467, 1473, 1478, 1540, 1524, 1527, 1530,

       78, 1533, 1536
    } ;

static yyconst flex_int16_t yy_def[204] =
    {   0,
      197,    1,  198,  198,  197,  197,  197,  197,  197,  199,
      200,  197,  197,  201,  201,  201,  201,  201,  201,  201,
      201,  201,  201,  201,  201,  201,  201,  201,  197,  202,
      203,  197,  197,  197,  199,  197,  200,  197,  197,  197,
      197,  197,  197,  197,  201,  197,  201,  201,  201,   49,
      201,  201,  201,  201,  201,  201,  201,  201,  201,  201,
      201,  201,  201,  201,  201,  201,  201,  201,  197,  202,
      197,  203,  197,  197,  197,  197,  197,  197,  197,  197,
      197,  197,  197,  197,  197,  197,  197,   49,  197,   49,
       49,  201,  201,  201,  201,  201,  201,  201,  201,  201,

      201,  201,  201,  201,  201,  201,  201,  201,  197,  197,
      197,  197,  197,  197,  197,  197,   49,   49,  201,  201,
      201,  201,  201,  201,  201,  201,  201,  201,  201,  201,
      201,  201,  201,  197,  197,  197,  197,  197,   49,  197,
       49,  201,  201,  201,  201,  201,  201,  201,  201,  201,
      201,  201,  201,  201,  201,  201,  197,  197,  197,  197,
      197,  197,  201,  197,  197,  201,  201,  201,  201,  201,
      201,  201,  201,  201,  201,  201,  201,  197,  197,  197,
      197,  201,  201,  201,  201,  201,  201,  201,  201,  201,
      201,  201,  201,  201,  201,  201,    0,  197,  197,  197,

      197,  197,  197
    } ;

static yyconst flex_int16_t yy_nxt[1606] =
    {   0,
        6,    7,    8,    9,   10,   11,   12,   13,   14,   14,
       14,   14,   14,   14,    6,   15,   16,   17,   18,   19,
       20,   21,   20,   20,   22,   20,   23,   20,   24,   25,
       26,   20,   27,   20,   20,   20,   28,   20,   20,   29,
       15,   16,   17,   18,   19,   20,   21,   20,   20,   22,
       23,   20,   24,   25,   26,   20,   27,   20,   20,   20,
       28,   20,   20,   30,    6,   39,   40,   40,   40,   40,
       40,   40,   41,   41,   41,   41,   41,   41,   42,   43,
       47,   44,   45,   45,   45,   45,   45,   45,   46,   71,
       69,   38,   48,   49,  197,  197,   50,  197,  197,  197,

       36,  197,  197,  197,  197,  197,   51,   53,  197,   74,
       75,  197,  197,   55,   69,   33,   71,   48,   49,   38,
       36,   50,   52,   34,   33,  197,  197,   54,  197,  197,
       51,  197,  197,   32,  197,  197,   32,  197,   55,  197,
       56,  197,  197,  197,  197,  197,   52,  197,  197,  197,
      197,   54,  197,   60,  197,  197,  197,  197,  197,  197,
       61,  197,  197,  197,  197,   56,  197,  197,  197,  197,
      197,  197,  197,  197,  197,  197,  197,  197,   60,   57,
      197,  197,  197,   62,  197,  197,  197,  197,   58,  197,
       63,  197,  197,   59,  197,  197,  197,  197,   64,  197,

      197,  197,  197,  197,   57,  197,  197,   62,  197,   65,
      197,   67,   58,  197,  197,   63,   66,   59,  197,  197,
      197,  197,   64,  197,  197,  197,  197,  197,  197,  197,
      197,  197,  197,   68,   65,   67,  197,  197,  197,  197,
       66,   73,   73,   73,   73,   73,   73,   87,   87,   87,
       87,   87,   87,  197,  197,  197,  197,  197,   68,   74,
       75,  197,   76,   40,   40,   40,   40,   40,   40,   46,
      197,  197,  197,   77,   78,  197,  197,   79,   91,   91,
       91,   91,   91,   91,  197,  197,  197,   80,  197,  197,
      197,  197,  197,  197,  197,  197,  197,  197,   77,   78,

      197,  197,   79,  197,  197,  197,  197,  197,  197,  197,
      197,   80,   81,   82,   92,  197,   41,   41,   41,   41,
       41,   41,  197,  197,  197,  197,   83,   84,  197,  197,
      197,   93,  197,   95,  197,  197,  197,  197,   92,  197,
       85,  197,  197,  197,  197,  197,  197,  197,  197,  197,
      197,   83,   84,  197,  197,  197,  197,   95,   96,  197,
      197,  197,  197,  197,   85,   42,   43,   94,  197,   41,
       41,   41,   41,   41,   41,  197,  197,  197,  197,   86,
       78,  197,  197,   96,  197,  197,  197,  197,  197,  197,
      197,   94,  197,   80,  197,  197,  197,  197,  197,  197,

      197,  197,  197,  197,   86,   78,   97,  197,  197,  197,
      197,   98,  197,  197,  197,  197,  197,   80,   42,   43,
      197,   44,   45,   45,   45,   45,   45,   45,   46,  197,
       97,   99,   48,   49,  197,   98,   50,  197,  197,  197,
      197,  101,  197,  197,  197,  197,   51,  197,  197,  197,
      197,  197,  197,  197,  197,   99,  197,   48,   49,  197,
      197,   50,  197,  197,  197,  197,  197,  120,  197,  197,
       51,  197,  197,  197,  197,   88,   88,   88,   88,   88,
       88,  197,  197,  197,   89,  197,   90,   90,   90,   90,
       90,   90,  197,  197,  197,  197,  197,  104,  197,  197,

      197,  197,  197,  197,  197,  197,  197,  197,  197,  197,
      197,  197,  197,  197,  197,  100,  102,  197,  197,  197,
      103,  104,  197,  197,  197,  197,  197,  197,  197,  197,
      197,  197,  197,  197,  197,  197,  197,  197,  197,  100,
      197,  102,  197,  105,  197,  103,  106,  111,  111,  111,
      111,  111,  111,  197,  197,  197,  197,  197,  107,   89,
      108,  112,  112,  112,  112,  112,  112,  197,  105,  197,
      106,  113,  113,  113,  113,  113,  113,  197,  197,  197,
      197,  197,  107,  197,  108,  109,  110,  197,  197,   73,
       73,   73,   73,   73,   73,  197,  197,  197,  197,   83,

       84,  114,  197,  115,  115,  115,  115,  115,  115,  197,
      197,  197,  197,   85,   87,   87,   87,   87,   87,   87,
      116,  197,  197,  197,   83,   84,  197,  197,  197,   88,
       88,   88,   88,   88,   88,  197,  197,   85,   74,   75,
      197,  197,   73,   73,   73,   73,   73,   73,  117,  197,
      197,  197,   86,   78,  112,  112,  112,  112,  112,  112,
      197,  197,  197,  197,  197,  197,   80,  197,  127,  197,
      197,  197,  117,  197,  197,  197,  197,   86,   78,  197,
      197,   91,   91,   91,   91,   91,   91,  197,  197,  197,
       80,  119,  197,  197,  197,  197,  197,  197,  197,  197,

      118,  197,  197,  197,  197,  121,  197,  197,  197,  197,
      197,  197,  197,  197,  197,  119,  197,  197,  197,  197,
      197,  197,  197,  197,  118,  197,  197,  122,  123,  197,
      121,  197,  124,  197,  197,  197,  197,  197,  197,  197,
      197,  197,  197,  197,  125,  197,  197,  197,  126,  197,
      197,  122,  197,  123,  197,  197,  197,  124,  197,  197,
      197,  197,  197,  197,  197,  197,  197,  197,  128,  125,
      197,  197,  197,  126,  197,  197,  197,  197,  197,  197,
      197,  197,  197,  197,  197,  197,  197,  197,  197,  129,
      197,  197,  197,  128,  197,  130,  197,  197,  197,  132,

      197,  197,  111,  111,  111,  111,  111,  111,  197,  131,
      197,  197,  197,  129,  197,  197,  197,  197,  197,  130,
      133,  134,   74,   75,  132,  197,  112,  112,  112,  112,
      112,  112,  145,  131,  113,  113,  113,  113,  113,  113,
      197,  197,  197,  197,  133,  134,  115,  115,  115,  115,
      115,  115,  197,  135,  109,  110,  197,  145,  115,  115,
      115,  115,  115,  115,  136,  137,  137,  137,  137,  137,
      137,  159,  159,  159,  159,  159,  159,  135,  197,  138,
      139,  139,  139,  139,  139,  139,  197,  140,  141,  141,
      141,  141,  141,  141,  197,  197,  197,  197,  197,  197,

      197,  197,  143,  197,  197,  197,  197,  197,  197,  197,
      197,  197,  197,  197,  197,  197,  142,  197,  197,  197,
      197,  197,  197,  197,  197,  197,  197,  197,  197,  197,
      197,  144,  197,  197,  197,  197,  197,  197,  197,  197,
      142,  197,  197,  146,  197,  197,  197,  197,  147,  197,
      197,  197,  197,  197,  150,  144,  197,  197,  197,  149,
      197,  197,  197,  197,  148,  197,  197,  146,  197,  197,
      197,  197,  147,  197,  197,  197,  197,  197,  151,  197,
      197,  197,  197,  197,  149,  197,  197,  197,  148,  152,
      197,  197,  197,  197,  197,  197,  197,  197,  197,  154,

      197,  197,  197,  151,  197,  197,  153,  161,  161,  161,
      161,  161,  161,  156,  152,  155,  138,  157,  157,  157,
      157,  157,  157,  197,  154,  197,  197,  197,  197,  197,
      153,  140,  158,  158,  158,  158,  158,  158,  156,  155,
      160,  137,  137,  137,  137,  137,  137,  197,  162,  139,
      139,  139,  139,  139,  139,  164,  164,  164,  164,  164,
      164,  197,  197,  197,  197,  197,  197,  197,  197,  197,
      197,  197,  197,  197,  163,  197,  197,  197,  197,  197,
      197,  197,  197,  197,  168,  197,  197,  197,  197,  197,
      197,  197,  167,  197,  197,  197,  197,  197,  163,  197,

      165,  141,  141,  141,  141,  141,  141,  197,  197,  168,
      197,  197,  197,  197,  197,  169,  167,  197,  197,  197,
      197,  197,  197,  197,  197,  197,  166,  197,  197,  197,
      197,  197,  197,  197,  197,  197,  170,  197,  197,  169,
      197,  197,  197,  171,  197,  173,  197,  197,  197,  197,
      166,  197,  172,  197,  197,  197,  197,  197,  197,  174,
      170,  197,  197,  197,  197,  197,  197,  171,  197,  197,
      173,  197,  197,  197,  197,  197,  172,  197,  197,  197,
      197,  197,  197,  197,  174,  197,  197,  175,  197,  197,
      162,  157,  157,  157,  157,  157,  157,  197,  197,  197,

      197,  176,  197,  197,  177,  159,  159,  159,  159,  159,
      159,  175,  197,  197,  197,  197,  178,  165,  158,  158,
      158,  158,  158,  158,  197,  176,  197,  197,  177,  159,
      159,  159,  159,  159,  159,  197,  197,  197,  197,  197,
      178,  197,  197,  179,  161,  161,  161,  161,  161,  161,
      161,  161,  161,  161,  161,  161,  197,  197,  197,  197,
      164,  164,  164,  164,  164,  164,  197,  179,  197,  180,
      197,  197,  197,  197,  197,  178,  164,  164,  164,  164,
      164,  164,  197,  197,  197,  181,  197,  197,  197,  197,
      197,  197,  197,  180,  197,  197,  197,  197,  197,  178,

      197,  179,  197,  197,  197,  197,  197,  197,  197,  181,
      197,  197,  197,  197,  197,  197,  197,  197,  197,  197,
      197,  197,  197,  182,  197,  179,  183,  197,  197,  197,
      197,  197,  197,  184,  197,  197,  197,  197,  197,  197,
      197,  197,  197,  197,  197,  197,  197,  182,  197,  197,
      197,  183,  197,  186,  197,  197,  197,  185,  184,  197,
      197,  197,  187,  197,  197,  197,  197,  197,  197,  189,
      197,  188,  197,  197,  197,  197,  197,  197,  186,  197,
      197,  185,  197,  197,  197,  197,  187,  197,  197,  197,
      197,  197,  197,  189,  197,  197,  188,  197,  197,  197,

      197,  197,  197,  190,  197,  197,  197,  197,  197,  197,
      191,  197,  197,  197,  197,  197,  197,  197,  197,  197,
      197,  197,  197,  197,  192,  197,  193,  190,  197,  197,
      197,  197,  197,  197,  197,  191,  197,  197,  197,  197,
      197,  197,  197,  197,  197,  197,  197,  197,  197,  192,
      197,  193,  194,  197,  197,  197,  197,  197,  197,  197,
      197,  197,  197,  197,  197,  197,  197,  197,  197,  197,
      195,  197,  197,  197,  197,  197,  194,  197,  197,  197,
      197,  197,  197,  197,  197,  197,  197,  197,  197,  197,
      197,  197,  197,  197,  197,  195,  197,  197,  197,  196,

      197,  197,  197,  197,  197,  197,  197,  197,  197,  197,
      197,  197,  197,  197,  197,  197,  197,  197,  197,  197,
      197,  197,  197,  196,   31,   31,   31,   35,  197,   35,
       37,  197,   37,   70,  197,   70,   72,  197,   72,    5,
      197,  197,  197,  197,  197,  197,  197,  197,  197,  197,
      197,  197,  197,  197,  197,  197,  197,  197,  197,  197,
      197,  197,  197,  197,  197,  197,  197,  197,  197,  197,
      197,  197,  197,  197,  197,  197,  197,  197,  197,  197,
      197,  197,  197,  197,  197,  197,  197,  197,  197,  197,
      197,  197,  197,  197,  197,  197,  197,  197,  197,  197,

      197,  197,  197,  197,  197
    } ;

static yyconst flex_int16_t yy_chk[1606] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,   12,   12,   12,   12,   12,
       12,   12,   13,   13,   13,   13,   13,   13,   14,   14,
      201,   14,   14,   14,   14,   14,   14,   14,   14,   70,
       29,   37,   14,   14,   17,   17,   14,   17,   15,   15,

       35,   15,   16,   16,   17,   16,   14,   16,   15,   90,
       90,   90,   16,   17,   29,   33,   30,   14,   14,   11,
       10,   14,   15,    9,    7,   18,   18,   16,   18,    5,
       14,   20,   20,    4,   20,   18,    3,    0,   17,    0,
       18,   20,   21,   21,    0,   21,   15,    0,    0,    0,
        0,   16,   21,   21,   22,   22,    0,   22,   23,   23,
       22,   23,    0,    0,   22,   18,   19,   19,   23,   19,
       24,   24,    0,   24,   25,   25,   19,   25,   21,   19,
       24,    0,    0,   23,   25,    0,   27,   27,   19,   27,
       25,   26,   26,   19,   26,    0,   27,    0,   25,    0,

        0,   26,    0,    0,   19,    0,    0,   23,    0,   26,
        0,   27,   19,    0,    0,   25,   26,   19,   28,   28,
        0,   28,   25,    0,    0,    0,   47,   47,   28,   47,
        0,    0,    0,   28,   26,   27,   47,    0,    0,    0,
       26,   39,   39,   39,   39,   39,   39,   46,   46,   46,
       46,   46,   46,    0,    0,    0,    0,    0,   28,   40,
       40,    0,   40,   40,   40,   40,   40,   40,   40,   40,
        0,    0,    0,   40,   40,    0,   50,   40,   50,   50,
       50,   50,   50,   50,    0,   51,   51,   40,   51,    0,
       52,   52,    0,   52,    0,   51,    0,    0,   40,   40,

       52,    0,   40,    0,    0,   55,   55,    0,   55,    0,
        0,   40,   41,   41,   52,   55,   41,   41,   41,   41,
       41,   41,   53,   53,    0,   53,   41,   41,    0,    0,
        0,   53,   53,   55,   54,   54,    0,   54,   52,    0,
       41,    0,    0,    0,   54,    0,   56,   56,    0,   56,
        0,   41,   41,    0,    0,    0,   56,   55,   56,    0,
        0,    0,    0,    0,   41,   44,   44,   54,    0,   44,
       44,   44,   44,   44,   44,    0,    0,    0,    0,   44,
       44,    0,    0,   56,   57,   57,    0,   57,    0,   58,
       58,   54,   58,   44,   57,    0,    0,    0,    0,   58,

       59,   59,    0,   59,   44,   44,   57,    0,    0,    0,
       59,   58,    0,    0,    0,    0,    0,   44,   45,   45,
        0,   45,   45,   45,   45,   45,   45,   45,   45,    0,
       57,   59,   45,   45,    0,   58,   45,   61,   61,    0,
       61,   61,   64,   64,    0,   64,   45,   61,    0,    0,
        0,    0,   64,    0,    0,   59,    0,   45,   45,   93,
       93,   45,   93,   65,   65,    0,   65,   93,    0,   93,
       45,   48,   48,   65,   48,   48,   48,   48,   48,   48,
       48,   48,   49,   49,   49,   49,   49,   49,   49,   49,
       49,   49,   49,   60,   60,    0,   60,   65,    0,   62,

       62,    0,   62,   60,   63,   63,    0,   63,    0,   62,
        0,    0,    0,    0,   63,   60,   62,    0,    0,    0,
       63,   65,    0,    0,   66,   66,    0,   66,   67,   67,
        0,   67,   68,   68,   66,   68,    0,    0,   67,   60,
        0,   62,   68,   66,    0,   63,   66,   77,   77,   77,
       77,   77,   77,    0,    0,    0,    0,    0,   67,   78,
       68,   78,   78,   78,   78,   78,   78,    0,   66,    0,
       66,   79,   79,   79,   79,   79,   79,   94,   94,    0,
       94,    0,   67,    0,   68,   73,   73,   94,    0,   73,
       73,   73,   73,   73,   73,    0,    0,    0,    0,   73,

       73,   84,    0,   84,   84,   84,   84,   84,   84,    0,
        0,    0,    0,   73,   87,   87,   87,   87,   87,   87,
       87,    0,    0,    0,   73,   73,    0,   88,    0,   88,
       88,   88,   88,   88,   88,    0,    0,   73,   76,   76,
        0,    0,   76,   76,   76,   76,   76,   76,   88,    0,
        0,    0,   76,   76,   89,   89,   89,   89,   89,   89,
       92,   92,    0,   92,  101,  101,   76,  101,  101,    0,
       92,    0,   88,    0,  101,    0,    0,   76,   76,   91,
        0,   91,   91,   91,   91,   91,   91,    0,    0,    0,
       76,   92,   95,   95,    0,   95,   96,   96,    0,   96,

       91,    0,   95,    0,    0,   95,   96,    0,    0,   97,
       97,    0,   97,   98,   98,   92,   98,    0,    0,   97,
        0,    0,    0,   98,   91,    0,    0,   96,   97,    0,
       95,    0,   98,   99,   99,    0,   99,  100,  100,    0,
      100,    0,    0,   99,   99,    0,    0,  100,  100,  102,
      102,   96,  102,   97,    0,  103,  103,   98,  103,  102,
      104,  104,    0,  104,    0,  103,    0,    0,  102,   99,
      104,  105,  105,  100,  105,  106,  106,    0,  106,    0,
        0,  105,    0,    0,    0,  106,    0,  107,  107,  104,
      107,  108,  108,  102,  108,  105,    0,  107,    0,  107,

        0,  108,  111,  111,  111,  111,  111,  111,    0,  106,
        0,    0,    0,  104,    0,  122,  122,    0,  122,  105,
      108,  111,  112,  112,  107,  122,  112,  112,  112,  112,
      112,  112,  122,  106,  113,  113,  113,  113,  113,  113,
        0,    0,    0,    0,  108,  111,  114,  114,  114,  114,
      114,  114,    0,  113,  115,  115,    0,  122,  115,  115,
      115,  115,  115,  115,  116,  116,  116,  116,  116,  116,
      116,  136,  136,  136,  136,  136,  136,  113,  117,  117,
      117,  117,  117,  117,  117,  117,  118,  118,  118,  118,
      118,  118,  118,  118,  119,  119,    0,  119,  120,  120,

        0,  120,  120,    0,  119,    0,    0,    0,  120,  121,
      121,    0,  121,    0,    0,    0,  119,  123,  123,  121,
      123,    0,  124,  124,    0,  124,    0,  123,    0,    0,
        0,  121,  124,    0,  125,  125,    0,  125,    0,    0,
      119,    0,    0,  123,  125,    0,  126,  126,  124,  126,
      127,  127,    0,  127,  127,  121,  126,    0,    0,  126,
      127,    0,    0,    0,  125,  128,  128,  123,  128,    0,
      129,  129,  124,  129,    0,  128,  130,  130,  128,  130,
      129,    0,  131,  131,  126,  131,  130,    0,  125,  129,
      132,  132,  131,  132,  133,  133,    0,  133,    0,  131,

      132,    0,    0,  128,  133,    0,  130,  138,  138,  138,
      138,  138,  138,  133,  129,  132,  134,  134,  134,  134,
      134,  134,  134,    0,  131,    0,    0,    0,    0,    0,
      130,  135,  135,  135,  135,  135,  135,  135,  133,  132,
      137,  137,  137,  137,  137,  137,  137,  139,  139,  139,
      139,  139,  139,  139,  139,  140,  140,  140,  140,  140,
      140,  142,  142,    0,  142,  143,  143,    0,  143,  144,
      144,  142,  144,    0,  139,  143,    0,  145,  145,  144,
      145,    0,    0,    0,  144,  146,  146,  145,  146,    0,
        0,    0,  142,    0,    0,  146,    0,    0,  139,  141,

      141,  141,  141,  141,  141,  141,  141,  147,  147,  144,
      147,    0,    0,    0,    0,  146,  142,  147,  148,  148,
        0,  148,  149,  149,    0,  149,  141,    0,  148,    0,
      150,  150,  149,  150,  151,  151,  147,  151,    0,  146,
      150,    0,    0,  148,  151,  151,  152,  152,    0,  152,
      141,    0,  149,    0,  153,  153,  152,  153,    0,  152,
      147,    0,  154,  154,  153,  154,    0,  148,  155,  155,
      151,  155,  154,    0,    0,    0,  149,    0,  155,  156,
      156,    0,  156,    0,  152,    0,    0,  154,    0,  156,
      157,  157,  157,  157,  157,  157,  157,    0,    0,    0,

        0,  155,    0,    0,  156,  159,  159,  159,  159,  159,
      159,  154,    0,    0,    0,    0,  157,  158,  158,  158,
      158,  158,  158,  158,    0,  155,    0,    0,  156,  160,
      160,  160,  160,  160,  160,    0,    0,    0,    0,    0,
      157,    0,    0,  158,  161,  161,  161,  161,  161,  161,
      162,  162,  162,  162,  162,  162,  163,  163,    0,  163,
      164,  164,  164,  164,  164,  164,  163,  158,    0,  161,
        0,    0,    0,    0,    0,  162,  165,  165,  165,  165,
      165,  165,    0,    0,    0,  164,  166,  166,    0,  166,
        0,    0,    0,  161,  167,  167,  166,  167,    0,  162,

        0,  165,  168,  168,  167,  168,    0,  169,  169,  164,
      169,    0,  168,    0,    0,    0,    0,  169,  170,  170,
        0,  170,    0,  167,    0,  165,  169,    0,  170,  171,
      171,    0,  171,  170,  172,  172,    0,  172,    0,  171,
      173,  173,    0,  173,  172,  175,  175,  167,  175,    0,
      173,  169,    0,  172,    0,  175,    0,  171,  170,    0,
      174,  174,  173,  174,  176,  176,    0,  176,    0,  175,
      174,  174,    0,    0,  176,    0,    0,    0,  172,  177,
      177,  171,  177,    0,  182,  182,  173,  182,    0,  177,
        0,    0,    0,  175,  182,    0,  174,  183,  183,    0,

      183,  184,  184,  177,  184,  185,  185,  183,  185,    0,
      183,  184,    0,  186,  186,  185,  186,    0,  187,  187,
        0,  187,    0,  186,  185,    0,  186,  177,  187,    0,
      188,  188,    0,  188,    0,  183,  189,  189,    0,  189,
      188,    0,    0,    0,  190,  190,  189,  190,    0,  185,
        0,  186,  188,    0,  190,  191,  191,    0,  191,  192,
      192,    0,  192,  193,  193,  191,  193,    0,    0,  192,
      192,  194,  194,  193,  194,    0,  188,  195,  195,    0,
      195,  194,  196,  196,    0,  196,    0,  195,    0,    0,
        0,    0,  196,    0,    0,  192,    0,    0,    0,  195,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,  195,  198,  198,  198,  199,    0,  199,
      200,    0,  200,  202,    0,  202,  203,    0,  203,  197,
      197,  197,  197,  197,  197,  197,  197,  197,  197,  197,
      197,  197,  197,  197,  197,  197,  197,  197,  197,  197,
      197,  197,  197,  197,  197,  197,  197,  197,  197,  197,
      197,  197,  197,  197,  197,  197,  197,  197,  197,  197,
      197,  197,  197,  197,  197,  197,  197,  197,  197,  197,
      197,  197,  197,  197,  197,  197,  197,  197,  197,  197,

      197,  197,  197,  197,  197
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "proslex.L"
/* Copyright (C) 1999-2015
 * Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 * For conditions of distribution and use, see copyright notice in "copyright"
 */
#line 12 "proslex.L"
  #include <stdio.h>
  #include <stdlib.h>
  #include <string.h>

  #include "util.h"
  #include "prosparser.H"

  extern YYSTYPE* proslval;
  extern prosFlexLexer* proslexx;

/* rules */
#line 846 "proslex.C"

#define INITIAL 0
#define DISCARD 1

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
#define ECHO LexerOutput( yytext, yyleng )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
\
	if ( (result = LexerInput( (char *) buf, max_size )) < 0 ) \
		YY_FATAL_ERROR( "input in flex scanner failed" );

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) LexerError( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1
#define YY_DECL int yyFlexLexer::yylex()
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 30 "proslex.L"


#line 950 "proslex.C"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = & std::cin;

		if ( ! yyout )
			yyout = & std::cout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 198 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 197 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 32 "proslex.L"
{ // special case-- #\n
		  BEGIN INITIAL;
		  yyless(0);             // put back the terminator
		  strcpy(proslval->str,""); // feed a blank string
		  return STRING;
		}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 39 "proslex.L"
{  // Discard reset of line
		  BEGIN INITIAL;
		  int ll = yyleng <(PROSBUFSIZE-1) ? yyleng:(PROSBUFSIZE-1);
		  strncpy(proslval->str,yytext,ll);
	          proslval->str[ll] = '\0';
		  return STRING;
		}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 47 "proslex.L"
{return ANNULUS_;}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 48 "proslex.L"
{return B1950_;}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 49 "proslex.L"
{return BOX_;}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 50 "proslex.L"
{return CIRCLE_;}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 51 "proslex.L"
{return DEBUG_;}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 52 "proslex.L"
{return ELLIPSE_;}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 53 "proslex.L"
{return ECLIPTIC_;}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 54 "proslex.L"
{return EQUATORIAL_;}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 55 "proslex.L"
{return GALACTIC_;}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 56 "proslex.L"
{return J2000_;}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 57 "proslex.L"
{return LOGICAL_;}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 58 "proslex.L"
{return N_;}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 59 "proslex.L"
{return OFF_;}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 60 "proslex.L"
{return ON_;}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 61 "proslex.L"
{return PHYSICAL_;}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 62 "proslex.L"
{return POINT_;}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 63 "proslex.L"
{return POLYGON_;}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 64 "proslex.L"
{return ROTBOX_;}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 65 "proslex.L"
{return VERSION_;}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 67 "proslex.L"
{ // Integer
		  proslval->integer = atoi(yytext);
		  return INT;
		}
	YY_BREAK
case 23:
#line 73 "proslex.L"
case 24:
YY_RULE_SETUP
#line 73 "proslex.L"
{ // Real Number
		  proslval->real = atof(yytext);
		  return REAL;
		}
	YY_BREAK
case 25:
#line 79 "proslex.L"
case 26:
YY_RULE_SETUP
#line 79 "proslex.L"
{ // degrees
		  yytext[yyleng-1] = '\0';
		  proslval->real = atof(yytext);
		  return ANGDEGREE;
		}	
	YY_BREAK
case 27:
#line 86 "proslex.L"
case 28:
YY_RULE_SETUP
#line 86 "proslex.L"
{ // radians
		  yytext[yyleng-1] = '\0';
		  proslval->real = atof(yytext);
		  return ANGRADIAN;
		}
	YY_BREAK
case 29:
#line 93 "proslex.L"
case 30:
#line 94 "proslex.L"
case 31:
#line 95 "proslex.L"
case 32:
YY_RULE_SETUP
#line 95 "proslex.L"
{ // minutes of arc
		  yytext[yyleng-1] = '\0';
		  proslval->real = atof(yytext);
		  return ARCMINUTE;
		}	
	YY_BREAK
case 33:
#line 102 "proslex.L"
case 34:
#line 103 "proslex.L"
case 35:
#line 104 "proslex.L"
case 36:
YY_RULE_SETUP
#line 104 "proslex.L"
{ // seconds of arc
		  yytext[yyleng-1] = '\0';
		  proslval->real = atof(yytext);
		  return ARCSECOND;
		}
	YY_BREAK
case 37:
#line 111 "proslex.L"
case 38:
YY_RULE_SETUP
#line 111 "proslex.L"
{ // Sexagesimal
		  int ll = yyleng <(PROSBUFSIZE-1) ? yyleng:(PROSBUFSIZE-1);
		  strncpy(proslval->str,yytext,ll);
	          proslval->str[ll] = '\0';
		  return SEXSTR;
		}	
	YY_BREAK
case 39:
#line 119 "proslex.L"
case 40:
YY_RULE_SETUP
#line 119 "proslex.L"
{ // HMS
		  int ll = yyleng <(PROSBUFSIZE-1) ? yyleng:(PROSBUFSIZE-1);
		  strncpy(proslval->str,yytext,ll);
	          proslval->str[ll] = '\0';
		  return HMSSTR;
		}	
	YY_BREAK
case 41:
#line 127 "proslex.L"
case 42:
YY_RULE_SETUP
#line 127 "proslex.L"
{ // DMS
		  int ll = yyleng <(PROSBUFSIZE-1) ? yyleng:(PROSBUFSIZE-1);
		  strncpy(proslval->str,yytext,ll);
	          proslval->str[ll] = '\0';
		  return DMSSTR;
		}	
	YY_BREAK
case 43:
#line 135 "proslex.L"
case 44:
YY_RULE_SETUP
#line 135 "proslex.L"
{ // Quoted String
		  int ll=(yyleng-2)<(PROSBUFSIZE-1)?(yyleng-2):(PROSBUFSIZE-1);
		  strncpy(proslval->str,yytext+1,ll); // skip the " " 
	          proslval->str[ll] = '\0'; // Remove the '"' 
		  return STRING;
		}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 142 "proslex.L"
{ // Quoted String
		  int ll=(yyleng-2)<(PROSBUFSIZE-1)?(yyleng-2):(PROSBUFSIZE-1);
		  strncpy(proslval->str,yytext+1,ll); // skip the '{'
	          proslval->str[ll] = '\0'; // Remove the '}'
		  return STRING;
		}
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 149 "proslex.L"
{ // General String
		  int ll = yyleng <(PROSBUFSIZE-1) ? yyleng:(PROSBUFSIZE-1);
		  strncpy(proslval->str,yytext,ll);
	          proslval->str[ll] = '\0';
		  return STRING;
		}
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 156 "proslex.L"
{ // White Spaces
		} 
	YY_BREAK
case 48:
/* rule 48 can match eol */
YY_RULE_SETUP
#line 159 "proslex.L"
{ // windows line feed
		  return '\n';
		}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 163 "proslex.L"
{ // fake line feed
		  return '\n';
		}
	YY_BREAK
case 50:
/* rule 50 can match eol */
YY_RULE_SETUP
#line 167 "proslex.L"
{ // linefeed
		  return '\n';
		}
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(DISCARD):
#line 171 "proslex.L"
{ // eof
		  return EOF_;
		}
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 175 "proslex.L"
{ // Else, return the char
		  return yytext[0];
		}
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 179 "proslex.L"
ECHO;
	YY_BREAK
#line 1332 "proslex.C"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* The contents of this function are C++ specific, so the () macro is not used.
 */
yyFlexLexer::yyFlexLexer( std::istream* arg_yyin, std::ostream* arg_yyout )
{
	yyin = arg_yyin;
	yyout = arg_yyout;
	yy_c_buf_p = 0;
	yy_init = 0;
	yy_start = 0;
	yy_flex_debug = 0;
	yylineno = 1;	// this will only get updated if %option yylineno

	yy_did_buffer_switch_on_eof = 0;

	yy_looking_for_trail_begin = 0;
	yy_more_flag = 0;
	yy_more_len = 0;
	yy_more_offset = yy_prev_more_offset = 0;

	yy_start_stack_ptr = yy_start_stack_depth = 0;
	yy_start_stack = NULL;

	yy_buffer_stack = 0;
	yy_buffer_stack_top = 0;
	yy_buffer_stack_max = 0;

	yy_state_buf = 0;

}

/* The contents of this function are C++ specific, so the () macro is not used.
 */
yyFlexLexer::~yyFlexLexer()
{
	delete [] yy_state_buf;
	prosfree(yy_start_stack  );
	yy_delete_buffer( YY_CURRENT_BUFFER );
	prosfree(yy_buffer_stack  );
}

/* The contents of this function are C++ specific, so the () macro is not used.
 */
void yyFlexLexer::switch_streams( std::istream* new_in, std::ostream* new_out )
{
	if ( new_in )
		{
		yy_delete_buffer( YY_CURRENT_BUFFER );
		yy_switch_to_buffer( yy_create_buffer( new_in, YY_BUF_SIZE  ) );
		}

	if ( new_out )
		yyout = new_out;
}

#ifdef YY_INTERACTIVE
size_t yyFlexLexer::LexerInput( char* buf, size_t /* max_size */ )
#else
size_t yyFlexLexer::LexerInput( char* buf, size_t max_size )
#endif
{
	if ( yyin->eof() || yyin->fail() )
		return 0;

#ifdef YY_INTERACTIVE
	yyin->get( buf[0] );

	if ( yyin->eof() )
		return 0;

	if ( yyin->bad() )
		return -1;

	return 1;

#else
	(void) yyin->read( buf, max_size );

	if ( yyin->bad() )
		return -1;
	else
		return yyin->gcount();
#endif
}

void yyFlexLexer::LexerOutput( const char* buf, size_t size )
{
	(void) yyout->write( buf, size );
}

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
int yyFlexLexer::yy_get_next_buffer()
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				yy_size_t new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					prosrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) prosrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    yy_state_type yyFlexLexer::yy_get_previous_state()
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 198 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    yy_state_type yyFlexLexer::yy_try_NUL_trans( yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 198 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 197);

	return yy_is_jam ? 0 : yy_current_state;
}

    void yyFlexLexer::yyunput( int c, register char* yy_bp)
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register yy_size_t number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

    int yyFlexLexer::yyinput()
{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyFlexLexer::yyrestart( std::istream* input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yyFlexLexer::yy_switch_to_buffer( YY_BUFFER_STATE new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

    void yyFlexLexer::yy_load_buffer_state()
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yyFlexLexer::yy_create_buffer( std::istream* file, int size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) prosalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) prosalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yyFlexLexer::yy_delete_buffer( YY_BUFFER_STATE b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		prosfree((void *) b->yy_ch_buf  );

	prosfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    void yyFlexLexer::yy_init_buffer( YY_BUFFER_STATE b, std::istream* file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

	b->yy_is_interactive = 0;
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yyFlexLexer::yy_flush_buffer( YY_BUFFER_STATE b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yyFlexLexer::yypush_buffer_state (YY_BUFFER_STATE new_buffer)
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yyFlexLexer::yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
void yyFlexLexer::yyensure_buffer_stack(void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)prosalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)prosrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

    void yyFlexLexer::yy_push_state( int new_state )
{
    	if ( (yy_start_stack_ptr) >= (yy_start_stack_depth) )
		{
		yy_size_t new_size;

		(yy_start_stack_depth) += YY_START_STACK_INCR;
		new_size = (yy_start_stack_depth) * sizeof( int );

		if ( ! (yy_start_stack) )
			(yy_start_stack) = (int *) prosalloc(new_size  );

		else
			(yy_start_stack) = (int *) prosrealloc((void *) (yy_start_stack),new_size  );

		if ( ! (yy_start_stack) )
			YY_FATAL_ERROR( "out of memory expanding start-condition stack" );
		}

	(yy_start_stack)[(yy_start_stack_ptr)++] = YY_START;

	BEGIN(new_state);
}

    void yyFlexLexer::yy_pop_state()
{
    	if ( --(yy_start_stack_ptr) < 0 )
		YY_FATAL_ERROR( "start-condition stack underflow" );

	BEGIN((yy_start_stack)[(yy_start_stack_ptr)]);
}

    int yyFlexLexer::yy_top_state()
{
    	return (yy_start_stack)[(yy_start_stack_ptr) - 1];
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

void yyFlexLexer::LexerError( yyconst char msg[] )
{
    	std::cerr << msg << std::endl;
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *prosalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *prosrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void prosfree (void * ptr )
{
	free( (char *) ptr );	/* see prosrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 179 "proslex.L"



void prosDiscard(int doit)
{
  if (proslexx)
    proslexx->begin(DISCARD, doit);
}

void prosFlexLexer::begin(int which, int doit)
{
  BEGIN which;
  if (doit)
    yyless(0);
}

